#
# spec file for package tree-sitter-javascript
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _name javascript
Name:           tree-sitter-javascript
Version:        0.23.1
Release:        1.2
Summary:        Javascript grammar for tree-sitter
License:        MIT
URL:            https://github.com/tree-sitter/tree-sitter-javascript
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  tree-sitter
%treesitter_grammars %{_name}

%description
%{summary}.

%prep
%autosetup

%build
%treesitter_configure
%treesitter_build

%install
%treesitter_install
%treesitter_devel_install

#neovim stuff
install -d %{buildroot}%{_libdir}/tree_sitter
ln -s %{_libdir}/lib%{name}.so %{buildroot}%{_libdir}/tree_sitter/%{_name}.so

%files
%license LICENSE
%treesitter_files
%{_libdir}/tree_sitter/%{_name}.so
%if 0%{?suse_version} < 1600
%dir %{_libdir}/tree_sitter
%endif

%treesitter_devel_package

%changelog
* Wed Dec  4 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.23.1:
  * build: update bindings
  * feat!: remove glimmer template tags
  * build: update bindings
  * fix(swift): add scanner.c to sources
- update to 0.23.0:
  * fix: operator precedence rules for tagged template functions
  * build: update bindings
  * fix(go): correct test
  * fix: move go.mod to root dir
  * fix: for in / of statements containing new lines
  * fix: disallow semi injection before a backtick
  * fix: add import.meta to meta_property
- update to 0.21.4:
  * fix: jsx_text node trims whitespace too often
  * fix: automatic semicolon should be inserted given a number decimal
  * fix: comment optimization should not cause automatic-semi insert
  * fix: unnecessary seq sequences
  * fix: comment should be terminal
- update to 0.21.3:
  * fix: comments should not consume 2028+2029, and neither should
    identifiers
  * feat(build): and add jsx
  * feat(build): add mjs and cjs file types
  * fix(build): use flag_if_supported for cc flags
- update to 0.21.2:
  * chore: bump deps
- update to 0.21.1:
  * chore: remove reset function
  * fix: un-inline statement
  * fix: only allow automatic_semicolons after static
  * chore: generate
  * fix: static can be on its own line
  * feat(queries): highlight glimmer tags
  * docs: update readme
  * build: update npm scripts and rust injection query name
- switch to download_files service
- add neovim links
- enable devel package
* Mon Apr 29 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 0.21.0:
  * fix: escape braces in regex
  * fix: allow ampersands not followed by `#` or a letter in jsx strings
  * refactor!: use last-wins precedence for queries
* Wed Mar 20 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 0.20.4:
  * fix: escape braces in regex
  * build(deps): bump deps
  * fix: allow ampersands not followed by `#` or a letter in jsx strings
  * refactor!: use last-wins precedence for queries
  * docs: update badges
  * chore: update tests
  * fix: do statements can have semicolons
  * fix: give ending regex `/` a higher lexical precedence
  * fix: don't parse html comments inside regexes
  * fix: tweak template literal injection
* Mon Feb 26 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Initial packaging for openSUSE
- Update to version 0.20.3:
  * chore: generate
  * fix: windows newline escapes
  * chore: don't greedily parse automatic semis if an `=` is present
  * feat: add support for import attributes
  * feat: add field names to nested_identifier rule
  * feat: support HTML entities in JSX text/attributes
  * chore: format scanner
  * fix: include parser.h locally
